@@ -61,9 +61,9 @@ extern "C" {
 #endif
 
 /* Enable/disable support for additional languages */
-#ifndef SUPPORT_LOCALIZATIONS
-#define SUPPORT_LOCALIZATIONS 1
-#endif
+// #ifndef SUPPORT_LOCALIZATIONS
+// #define SUPPORT_LOCALIZATIONS 1
+// #endif
 
 
 /* Convenience defines for Mac platforms */
